@@ -16,6 +16,8 @@ mod prelude {
         character::complete::multispace1,
         multi::many1,
     };
+    extern crate derive_more;
+    pub use derive_more::From;
 }
 
 pub mod basic;
