@@ -1,4 +1,4 @@
-use crate::{prelude::*, Identifier, LiteralExpr, Separator, Value};
+use crate::{prelude::*, Identifier, Ip, LiteralExpr, Separator, Value};
 use crate::{BytesUnit, DurationUnit, Filter, LabelFilterOp, LabelFilterType, MatchOp};
 
 #[derive(PartialEq, Debug, Clone)]
@@ -26,7 +26,7 @@ impl Parser for LogExpr {
     }
 }
 
-#[derive(derive_newtype::NewType, Eq, PartialEq, Debug, Clone)]
+#[derive(From, Eq, PartialEq, Debug, Clone)]
 pub struct Selector(Option<Matchers>);
 
 impl Parser for Selector {
@@ -239,7 +239,7 @@ impl Parser for LabelFilter {
 #[derive(Eq, PartialEq, Debug, Clone)]
 pub struct IpTableFilter {
     key: Identifier,
-    val: Value,
+    val: Ip,
     op: MatchOp,
 }
 
@@ -258,7 +258,7 @@ impl Parser for IpTableFilter {
                 opt(Separator::parse),
                 cchar('('),
                 opt(Separator::parse),
-                Value::parse,
+                Ip::parse,
                 opt(Separator::parse),
                 cchar(')'),
             )),
@@ -538,7 +538,7 @@ impl Parser for LabelParserType {
     }
 }
 
-#[derive(derive_newtype::NewType, Eq, PartialEq, Debug, Clone)]
+#[derive(From, Eq, PartialEq, Debug, Clone)]
 pub struct Matchers(Vec<Matcher>);
 
 impl Parser for Matchers {
@@ -584,13 +584,15 @@ impl From<(Filter, bool, &str)> for LineFilter {
     }
 }
 
-impl From<(&str, &str, crate::MatchOp)> for IpTableFilter {
-    fn from(from: (&str, &str, MatchOp)) -> Self {
-        Self {
+impl TryFrom<(&str, &str, crate::MatchOp)> for IpTableFilter {
+    type Error = std::net::AddrParseError;
+
+    fn try_from(from: (&str, &str, crate::MatchOp)) -> Result<Self, Self::Error> {
+        Ok(Self {
             key: Identifier::from(from.0.to_string()),
-            val: Value::from(from.1.to_string()),
+            val: Ip::from(from.1.parse::<std::net::IpAddr>()?),
             op: from.2,
-        }
+        })
     }
 }
 
@@ -853,7 +855,7 @@ mod tests {
                 .1,
             IpTableFilter {
                 key: Identifier::from("abc".to_string()),
-                val: Value::from("1.1.1.1".to_string()),
+                val: Ip::from("1.1.1.1".parse::<std::net::IpAddr>().unwrap()),
                 op: MatchOp::EQ
             }
         );
@@ -1017,11 +1019,11 @@ mod tests {
                 PipelineStage::LabelParser(LabelParserExpr(LabelParserType::REGEXP(
                     Value::from(r#"(?P<method>\\w+) (?P<path>[\\w|/]+) \\((?P<status>\\d+?)\\) (?P<duration>.*)"#.to_string())
                 ))),
-                PipelineStage::LabelFilters(LabelFilters::Single(LabelFilter::IpTable(("b", "127.0.0.1", MatchOp::EQ).into()),)),
+                PipelineStage::LabelFilters(LabelFilters::Single(LabelFilter::IpTable(("b", "127.0.0.1", MatchOp::EQ).try_into().unwrap()),)),
                 PipelineStage::LabelFilters(LabelFilters::Single(LabelFilter::Matcher(("level", "error", MatchOp::EQ).into()),)),
                 PipelineStage::LabelFilters(LabelFilters::Compose {
                     op: LabelFilterOp::AND,
-                    lhs: Box::new(LabelFilters::Single(LabelFilter::IpTable(("c", "::1", MatchOp::EQ).into()),)),
+                    lhs: Box::new(LabelFilters::Single(LabelFilter::IpTable(("c", "::1", MatchOp::EQ).try_into().unwrap()),)),
                     rhs: Box::new(LabelFilters::Single(LabelFilter::Matcher(("method", "2..", MatchOp::NRE).into()))) }),
                 ])
             )
@@ -1030,7 +1032,7 @@ mod tests {
         assert_eq!(
             LogExpr::parse(r#"{app="foo"} |= "bar"  | logfmt| latency >= 250ms or ( status_code < 500 and status_code > 200)"#).unwrap().1,
             LogExpr::PipelineExpr(
-                Selector(Some(Matchers(vec![("app", "foo", MatchOp::EQ).into()]))), 
+                Selector(Some(Matchers(vec![("app", "foo", MatchOp::EQ).into()]))),
                 PipelineExpr(vec![
                     PipelineStage::LineFilters(LineFilters(vec![LineFilter{ filter: Filter::PipeExact, filter_ip: false, val: Value::from("bar".to_string()) }])),
                     PipelineStage::LabelParser(LabelParserExpr(LabelParserType::LOGFMT)),
